==> ocg_app-0.0.33.tar.gz: lib/src/helpers/file_helper.dart <==
import 'dart:io';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:image_cropper/image_cropper.dart';
import 'package:image_picker/image_picker.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_app/src/models/data.dart';
import 'package:path_provider/path_provider.dart';
import 'package:video_thumbnail/video_thumbnail.dart';

class FileHelper {
  final BuildContext context;

  FileHelper.of(this.context);

  Future<AppResponse<ImageData>> pickImage({bool isCropped = true}) async {
    var result = await AppUIHelper.of(context)
        .showBottomSheet(title: "Pick Image", options: ["Image", "Gallery"]);
    AppResponse<File> response;
    switch (result) {
      case 0:
        response = await pickFromGalley(isCropped: true);
        break;
      case 1:
        response = await pickFromCamera(isCropped: true);
        break;
      default:
    }
    if (response != null && response.isSuccess) {
      return AppResponse.named(data: ImageData.named(url: response.data.path));
    }
    return AppResponse.named(error: "Not found");
  }

  Future<AppResponse<VideoData>> pickVideo({bool isThumbnail = false}) async {
    AppResponse<File> response;
    response = await pickFromGalley(isVideo: true);
    if (response != null && response.isSuccess) {
      String videoPath = response.data.path;
      var thumbnailResponse = await createThumbnail(videoPath);
      if (thumbnailResponse.isSuccess) {
        return AppResponse.named(
            data: VideoData.named(
                thumbnail: thumbnailResponse.data, url: videoPath));
      } else {
        return AppResponse.named(data: VideoData.named(url: videoPath));
      }
    }
    return response ?? AppResponse.named(error: "Error");
  }

  Future<AppResponse<File>> pickFile() async {
    FilePickerResult response = await FilePicker.platform.pickFiles();
    if (response != null && response.count > 0) {
      return AppResponse.named(data: File(response.files[0].path));
    } else {
      return AppResponse.named(error: "Not picked");
    }
  }

  Future<AppResponse<String>> createThumbnail(String videoPath) async {
    try {
      String path = (await getTemporaryDirectory()).path;
      var thumbnail = await VideoThumbnail.thumbnailFile(
          video: videoPath,
          imageFormat: ImageFormat.JPEG,
          thumbnailPath: path,
          quality: 50);
      return AppResponse.named(data: thumbnail);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<File>> pickFromCamera(
      {bool isVideo = false, int quality = 100, bool isCropped = false}) async {
    try {
      PickedFile file;
      if (!isVideo) {
        file = await ImagePicker()
            .getImage(source: ImageSource.camera, imageQuality: quality);
        if (isCropped) {
          File temp = await ImageCropper.cropImage(sourcePath: file.path);
          if (temp != null) {
            return AppResponse.named(data: temp);
          }
        }
      } else {
        file = await ImagePicker().getVideo(
          source: ImageSource.camera,
        );
      }
      return AppResponse.named(data: File(file.path));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<File>> pickFromGalley(
      {bool isVideo = false, int quality = 100, bool isCropped = false}) async {
    try {
      PickedFile file;
      if (!isVideo) {
        file = await ImagePicker()
            .getImage(source: ImageSource.gallery, imageQuality: quality);
        if (isCropped) {
          File temp = await ImageCropper.cropImage(sourcePath: file.path);
          if (temp != null) {
            return AppResponse.named(data: temp);
          }
        }
      } else {
        var files = await FilePicker.platform.pickFiles(
          allowMultiple: false,
          allowCompression: true,
          type: FileType.video,
        );
        if (files != null && files.count > 0) {
          return AppResponse.named(data: File(files.files[0].path));
        } else {
          return AppResponse.named(error: "Video not picked");
        }
      }
      return AppResponse.named(data: File(file.path));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  // Future<AppResponse<VideoData>> uploadVideo(
  //     UploadRepository uploadRepository, VideoData fileData) async {
  //   String uploadedVideo, uploadedThumbnail;
  //   try {
  //     await Future.wait([
  //       Future(() async {
  //         AppResponse<String> response = await uploadRepository.storeFile(
  //             File(fileData.videoPath),
  //             path: "videos/" + Uuid().v4());
  //         if (response.isSuccess) {
  //           uploadedVideo = response.data;
  //           debugPrint("Uploaded $uploadedVideo");
  //         }
  //       }),
  //       Future(() async {
  //         AppResponse<String> response = await uploadRepository.storeFile(
  //             File(fileData.thumbnailPath),
  //             path: "thumnbnail/" + Uuid().v4());
  //         if (response.isSuccess) {
  //           uploadedThumbnail = response.data;
  //           debugPrint("Uploaded Thumbnnail $uploadedThumbnail");
  //         }
  //       }),
  //     ]);
  //     if (uploadedVideo != null) {
  //       return AppResponse.named(
  //           data: VideoData.named(
  //               videoPath: uploadedVideo, thumbnailPath: uploadedThumbnail));
  //     }
  //     return AppResponse.named(error: "Video not uploaded");
  //   } catch (e) {
  //     return AppResponse.named(error: "${e.toString()}");
  //   }
  // }
}

==> ocg_app-0.0.38.tar.gz: lib/src/helpers/file_helper.dart <==
import 'dart:io';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:image_cropper/image_cropper.dart';
import 'package:image_picker/image_picker.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_app/src/models/data.dart';
import 'package:path_provider/path_provider.dart';
import 'package:video_thumbnail/video_thumbnail.dart';

class FileHelper {
  final BuildContext context;

  FileHelper.of(this.context);

  Future<AppResponse<ImageData>> pickImage({bool isCropped = true}) async {
    var result = await AppUIHelper.of(context)
        .showBottomSheet(title: "Pick Image", options: ["Gallery", "Camera"]);
    AppResponse<File> response;
    switch (result) {
      case 0:
        response = await pickFromGalley(isCropped: true);
        break;
      case 1:
        response = await pickFromCamera(isCropped: true);
        break;
      default:
    }
    if (response != null && response.isSuccess) {
      return AppResponse.named(data: ImageData.named(url: response.data.path));
    }
    return AppResponse.named(error: "Not found");
  }

  Future<AppResponse<VideoData>> pickVideo({bool isThumbnail = false}) async {
    AppResponse<File> response;
    response = await pickFromGalley(isVideo: true);
    if (response != null && response.isSuccess) {
      String videoPath = response.data.path;
      var thumbnailResponse = await createThumbnail(videoPath);
      if (thumbnailResponse.isSuccess) {
        return AppResponse.named(
            data: VideoData.named(
                thumbnail: thumbnailResponse.data, url: videoPath));
      } else {
        return AppResponse.named(data: VideoData.named(url: videoPath));
      }
    }
    return response ?? AppResponse.named(error: "Error");
  }

  Future<AppResponse<FileData>> pickFile() async {
    FilePickerResult response = await FilePicker.platform.pickFiles();
    if (response != null && response.count > 0) {
      return AppResponse.named(data: FileData(response.files[0].path));
    } else {
      return AppResponse.named(error: "Not picked");
    }
  }

  Future<AppResponse<String>> createThumbnail(String videoPath) async {
    try {
      String path = (await getTemporaryDirectory()).path;
      var thumbnail = await VideoThumbnail.thumbnailFile(
          video: videoPath,
          imageFormat: ImageFormat.JPEG,
          thumbnailPath: path,
          quality: 50);
      return AppResponse.named(data: thumbnail);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<File>> pickFromCamera(
      {bool isVideo = false, int quality = 100, bool isCropped = false}) async {
    try {
      PickedFile file;
      if (!isVideo) {
        file = await ImagePicker()
            .getImage(source: ImageSource.camera, imageQuality: quality);
        if (isCropped) {
          File temp = await ImageCropper.cropImage(sourcePath: file.path);
          if (temp != null) {
            return AppResponse.named(data: temp);
          }
        }
      } else {
        file = await ImagePicker().getVideo(
          source: ImageSource.camera,
        );
      }
      return AppResponse.named(data: File(file.path));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<File>> pickFromGalley(
      {bool isVideo = false, int quality = 100, bool isCropped = false}) async {
    try {
      var files = await FilePicker.platform.pickFiles(
        allowMultiple: false,
        allowCompression: true,
        type: isVideo ? FileType.video : FileType.image,
      );
      if (files != null && files.count > 0) {
        return AppResponse.named(data: File(files.files[0].path));
      } else {
        return AppResponse.named(error: "File not picked");
      }
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  // Future<AppResponse<VideoData>> uploadVideo(
  //     UploadRepository uploadRepository, VideoData fileData) async {
  //   String uploadedVideo, uploadedThumbnail;
  //   try {
  //     await Future.wait([
  //       Future(() async {
  //         AppResponse<String> response = await uploadRepository.storeFile(
  //             File(fileData.videoPath),
  //             path: "videos/" + Uuid().v4());
  //         if (response.isSuccess) {
  //           uploadedVideo = response.data;
  //           debugPrint("Uploaded $uploadedVideo");
  //         }
  //       }),
  //       Future(() async {
  //         AppResponse<String> response = await uploadRepository.storeFile(
  //             File(fileData.thumbnailPath),
  //             path: "thumnbnail/" + Uuid().v4());
  //         if (response.isSuccess) {
  //           uploadedThumbnail = response.data;
  //           debugPrint("Uploaded Thumbnnail $uploadedThumbnail");
  //         }
  //       }),
  //     ]);
  //     if (uploadedVideo != null) {
  //       return AppResponse.named(
  //           data: VideoData.named(
  //               videoPath: uploadedVideo, thumbnailPath: uploadedThumbnail));
  //     }
  //     return AppResponse.named(error: "Video not uploaded");
  //   } catch (e) {
  //     return AppResponse.named(error: "${e.toString()}");
  //   }
  // }
}
